@@ -7,12 +7,12 @@ class EntityUrlMap:
     _BASE_URL = 'api/'
 
     if config_profile.PROFILE == Constants.DEVELOP:
-        _HOST_INSTITUTION = 'http://192.168.0.12:8091/institutions/'
-        _HOST_USER = 'http://192.168.0.12:8092/users/'
-        _HOST_PUBLICATION = 'http://192.168.0.12:8093/publications/'
-        _HOST_CHAT = 'http://192.168.0.12:8097/chats/'
-        _HOST_SECURITY = 'http://192.168.0.12:8094/securities/'
-        _HOST_NOTIFICATION = 'http://192.168.0.12:8098/notifications/'
+        _HOST_INSTITUTION = 'http://192.168.0.11:8091/institutions/'
+        _HOST_USER = 'http://192.168.0.11:8092/users/'
+        _HOST_PUBLICATION = 'http://192.168.0.11:8093/publications/'
+        _HOST_CHAT = 'http://192.168.0.11:8097/chats/'
+        _HOST_SECURITY = 'http://192.168.0.11:8094/securities/'
+        _HOST_NOTIFICATION = 'http://192.168.0.11:8098/notifications/'
     else:
         _HOST_INSTITUTION = 'http://127.0.0.1:8091/institutions/'
         _HOST_USER = 'http://127.0.0.1:8092/users/'
@@ -28,6 +28,6 @@ class EntityUrlMap:
     CHAT = f'{_HOST_CHAT}{_BASE_URL}chat/'
     CONVERSATION = f'{_HOST_CHAT}{_BASE_URL}conversation/'
     INSTITUTION = f'{_HOST_INSTITUTION}{_BASE_URL}institution/'
-    JOB_OFFER = f'{_HOST_INSTITUTION}{_BASE_URL}job_offer/'
+    OPPORTUNITY = f'{_HOST_INSTITUTION}{_BASE_URL}opportunity/'
     PUBLICATION = f'{_HOST_PUBLICATION}{_BASE_URL}publication/'
     NOTIFICATION = f'{_HOST_NOTIFICATION}{_BASE_URL}notification/'
